@@ -46,4 +46,7 @@ if 1:
     print("1")
 
 if 2:
-    print("2")
\ No newline at end of file
+    print("2")
+
+if []:
+    print("ssss")
\ No newline at end of file
